SpringDescription

Struct SpringDescription 

pub struct SpringDescription<Scalar> {
    pub frequency: Scalar,
    pub damping: Scalar,
    pub initial_response: Scalar,
}
An intuitive description of the spring system from which SpringParameters can be built (Using Into::into)

Fields

frequency: Scalar

f, the natural frequency

Corresponds to:

  • The speed at which the system responds to changes in input
  • The frequency at which the system will vibrate
damping: Scalar

Zeta, the damping coefficient

Describes how fast the system settles to its target:

  • 0 (undamped): vibration never dies
  • 0 < Zeta <= 1 (underdamped): vibration dies
  • Zeta > 1: system does not vibrate, but approaches its target
initial_response: Scalar

r, the initial response

  • Negative: system anticipates motion by going in the opposite direction shortly
  • 0: system takes time to begin accelerating from rest
  • Positive: system immediately reacts to changes
  • r > 1: system overshoots target at first